==> citrus-ssh-4.0.0-sources.jar: org/citrusframework/model/config/ssh/SshClientModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.3 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.config.ssh;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlID;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java-Klasse für anonymous complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="id" use="required" type="{http://www.w3.org/2001/XMLSchema}ID" />
 *       <attribute name="host" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="port" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="private-key-path" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="private-key-password" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="user" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="password" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="strict-host-checking" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="known-hosts-path" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="command-timeout" type="{http://www.w3.org/2001/XMLSchema}int" />
 *       <attribute name="connection-timeout" type="{http://www.w3.org/2001/XMLSchema}int" />
 *       <attribute name="actor" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-correlator" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-converter" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="timeout" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="polling-interval" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "client")
public class SshClientModel {

    @XmlAttribute(name = "id", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAttribute(name = "host")
    protected String host;
    @XmlAttribute(name = "port")
    protected String port;
    @XmlAttribute(name = "private-key-path")
    protected String privateKeyPath;
    @XmlAttribute(name = "private-key-password")
    protected String privateKeyPassword;
    @XmlAttribute(name = "user", required = true)
    protected String user;
    @XmlAttribute(name = "password")
    protected String password;
    @XmlAttribute(name = "strict-host-checking")
    protected Boolean strictHostChecking;
    @XmlAttribute(name = "known-hosts-path")
    protected String knownHostsPath;
    @XmlAttribute(name = "command-timeout")
    protected Integer commandTimeout;
    @XmlAttribute(name = "connection-timeout")
    protected Integer connectionTimeout;
    @XmlAttribute(name = "actor")
    protected String actor;
    @XmlAttribute(name = "message-correlator")
    protected String messageCorrelator;
    @XmlAttribute(name = "message-converter")
    protected String messageConverter;
    @XmlAttribute(name = "timeout")
    protected String timeout;
    @XmlAttribute(name = "polling-interval")
    protected String pollingInterval;

    /**
     * Ruft den Wert der id-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Legt den Wert der id-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Ruft den Wert der host-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHost() {
        return host;
    }

    /**
     * Legt den Wert der host-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHost(String value) {
        this.host = value;
    }

    /**
     * Ruft den Wert der port-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPort() {
        return port;
    }

    /**
     * Legt den Wert der port-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPort(String value) {
        this.port = value;
    }

    /**
     * Ruft den Wert der privateKeyPath-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPrivateKeyPath() {
        return privateKeyPath;
    }

    /**
     * Legt den Wert der privateKeyPath-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPrivateKeyPath(String value) {
        this.privateKeyPath = value;
    }

    /**
     * Ruft den Wert der privateKeyPassword-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPrivateKeyPassword() {
        return privateKeyPassword;
    }

    /**
     * Legt den Wert der privateKeyPassword-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPrivateKeyPassword(String value) {
        this.privateKeyPassword = value;
    }

    /**
     * Ruft den Wert der user-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUser() {
        return user;
    }

    /**
     * Legt den Wert der user-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUser(String value) {
        this.user = value;
    }

    /**
     * Ruft den Wert der password-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPassword() {
        return password;
    }

    /**
     * Legt den Wert der password-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPassword(String value) {
        this.password = value;
    }

    /**
     * Ruft den Wert der strictHostChecking-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isStrictHostChecking() {
        return strictHostChecking;
    }

    /**
     * Legt den Wert der strictHostChecking-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setStrictHostChecking(Boolean value) {
        this.strictHostChecking = value;
    }

    /**
     * Ruft den Wert der knownHostsPath-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getKnownHostsPath() {
        return knownHostsPath;
    }

    /**
     * Legt den Wert der knownHostsPath-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setKnownHostsPath(String value) {
        this.knownHostsPath = value;
    }

    /**
     * Ruft den Wert der commandTimeout-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getCommandTimeout() {
        return commandTimeout;
    }

    /**
     * Legt den Wert der commandTimeout-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setCommandTimeout(Integer value) {
        this.commandTimeout = value;
    }

    /**
     * Ruft den Wert der connectionTimeout-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getConnectionTimeout() {
        return connectionTimeout;
    }

    /**
     * Legt den Wert der connectionTimeout-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setConnectionTimeout(Integer value) {
        this.connectionTimeout = value;
    }

    /**
     * Ruft den Wert der actor-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getActor() {
        return actor;
    }

    /**
     * Legt den Wert der actor-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setActor(String value) {
        this.actor = value;
    }

    /**
     * Ruft den Wert der messageCorrelator-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageCorrelator() {
        return messageCorrelator;
    }

    /**
     * Legt den Wert der messageCorrelator-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageCorrelator(String value) {
        this.messageCorrelator = value;
    }

    /**
     * Ruft den Wert der messageConverter-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageConverter() {
        return messageConverter;
    }

    /**
     * Legt den Wert der messageConverter-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageConverter(String value) {
        this.messageConverter = value;
    }

    /**
     * Ruft den Wert der timeout-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTimeout() {
        return timeout;
    }

    /**
     * Legt den Wert der timeout-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTimeout(String value) {
        this.timeout = value;
    }

    /**
     * Ruft den Wert der pollingInterval-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPollingInterval() {
        return pollingInterval;
    }

    /**
     * Legt den Wert der pollingInterval-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPollingInterval(String value) {
        this.pollingInterval = value;
    }

}

==> citrus-ssh-4.1.1-sources.jar: org/citrusframework/model/config/ssh/SshClientModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.4 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.config.ssh;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlID;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java-Klasse für anonymous complex type.</p>
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="id" use="required" type="{http://www.w3.org/2001/XMLSchema}ID" />
 *       <attribute name="host" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="port" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="private-key-path" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="private-key-password" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="user" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="password" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="strict-host-checking" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="known-hosts-path" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="command-timeout" type="{http://www.w3.org/2001/XMLSchema}int" />
 *       <attribute name="connection-timeout" type="{http://www.w3.org/2001/XMLSchema}int" />
 *       <attribute name="actor" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-correlator" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-converter" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="timeout" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="polling-interval" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "client")
public class SshClientModel {

    @XmlAttribute(name = "id", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    /**
     * Host to connect to for sending an SSH Exec request. Default is 'localhost'
     * 
     */
    @XmlAttribute(name = "host")
    protected String host;
    /**
     * Port to use. Default is 2222
     * 
     */
    @XmlAttribute(name = "port")
    protected String port;
    /**
     * Path to a private key, which can be either a plain file path or an class resource
     *             if prefixed with 'classpath:'
     * 
     */
    @XmlAttribute(name = "private-key-path")
    protected String privateKeyPath;
    /**
     * Optional password for the private key
     * 
     */
    @XmlAttribute(name = "private-key-password")
    protected String privateKeyPassword;
    /**
     * User used for connecting to the SSH server.
     * 
     */
    @XmlAttribute(name = "user", required = true)
    protected String user;
    /**
     * Password used for password based authentication. Might be combined
     *             with "private-key-path" in which case both authentication mechanism are tried.
     * 
     */
    @XmlAttribute(name = "password")
    protected String password;
    /**
     * Whether the host key should be verified by looking it up in a 'known_hosts' file.
     *             Default is false.
     * 
     */
    @XmlAttribute(name = "strict-host-checking")
    protected Boolean strictHostChecking;
    /**
     * Path to a known hosts file. If prefixed with 'classpath:' this file is looked up as
     *             a resource in the classpath.
     * 
     */
    @XmlAttribute(name = "known-hosts-path")
    protected String knownHostsPath;
    /**
     * Timeout in milliseconds for how long to wait for the SSH command to complete.
     *             Default is 5 minutes.
     * 
     */
    @XmlAttribute(name = "command-timeout")
    protected Integer commandTimeout;
    /**
     * Timeout in milliseconds for how long to for a connectiuon to connect.
     *             Default is 1 minute.
     * 
     */
    @XmlAttribute(name = "connection-timeout")
    protected Integer connectionTimeout;
    /**
     * Actor used for switching groups of actions. See the reference documentation
     *             for details.
     * 
     */
    @XmlAttribute(name = "actor")
    protected String actor;
    @XmlAttribute(name = "message-correlator")
    protected String messageCorrelator;
    @XmlAttribute(name = "message-converter")
    protected String messageConverter;
    @XmlAttribute(name = "timeout")
    protected String timeout;
    @XmlAttribute(name = "polling-interval")
    protected String pollingInterval;

    /**
     * Ruft den Wert der id-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Legt den Wert der id-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Host to connect to for sending an SSH Exec request. Default is 'localhost'
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHost() {
        return host;
    }

    /**
     * Legt den Wert der host-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getHost()
     */
    public void setHost(String value) {
        this.host = value;
    }

    /**
     * Port to use. Default is 2222
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPort() {
        return port;
    }

    /**
     * Legt den Wert der port-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getPort()
     */
    public void setPort(String value) {
        this.port = value;
    }

    /**
     * Path to a private key, which can be either a plain file path or an class resource
     *             if prefixed with 'classpath:'
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPrivateKeyPath() {
        return privateKeyPath;
    }

    /**
     * Legt den Wert der privateKeyPath-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getPrivateKeyPath()
     */
    public void setPrivateKeyPath(String value) {
        this.privateKeyPath = value;
    }

    /**
     * Optional password for the private key
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPrivateKeyPassword() {
        return privateKeyPassword;
    }

    /**
     * Legt den Wert der privateKeyPassword-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getPrivateKeyPassword()
     */
    public void setPrivateKeyPassword(String value) {
        this.privateKeyPassword = value;
    }

    /**
     * User used for connecting to the SSH server.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUser() {
        return user;
    }

    /**
     * Legt den Wert der user-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getUser()
     */
    public void setUser(String value) {
        this.user = value;
    }

    /**
     * Password used for password based authentication. Might be combined
     *             with "private-key-path" in which case both authentication mechanism are tried.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPassword() {
        return password;
    }

    /**
     * Legt den Wert der password-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getPassword()
     */
    public void setPassword(String value) {
        this.password = value;
    }

    /**
     * Whether the host key should be verified by looking it up in a 'known_hosts' file.
     *             Default is false.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isStrictHostChecking() {
        return strictHostChecking;
    }

    /**
     * Legt den Wert der strictHostChecking-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     * @see #isStrictHostChecking()
     */
    public void setStrictHostChecking(Boolean value) {
        this.strictHostChecking = value;
    }

    /**
     * Path to a known hosts file. If prefixed with 'classpath:' this file is looked up as
     *             a resource in the classpath.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getKnownHostsPath() {
        return knownHostsPath;
    }

    /**
     * Legt den Wert der knownHostsPath-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getKnownHostsPath()
     */
    public void setKnownHostsPath(String value) {
        this.knownHostsPath = value;
    }

    /**
     * Timeout in milliseconds for how long to wait for the SSH command to complete.
     *             Default is 5 minutes.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getCommandTimeout() {
        return commandTimeout;
    }

    /**
     * Legt den Wert der commandTimeout-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     * @see #getCommandTimeout()
     */
    public void setCommandTimeout(Integer value) {
        this.commandTimeout = value;
    }

    /**
     * Timeout in milliseconds for how long to for a connectiuon to connect.
     *             Default is 1 minute.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getConnectionTimeout() {
        return connectionTimeout;
    }

    /**
     * Legt den Wert der connectionTimeout-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     * @see #getConnectionTimeout()
     */
    public void setConnectionTimeout(Integer value) {
        this.connectionTimeout = value;
    }

    /**
     * Actor used for switching groups of actions. See the reference documentation
     *             for details.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getActor() {
        return actor;
    }

    /**
     * Legt den Wert der actor-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getActor()
     */
    public void setActor(String value) {
        this.actor = value;
    }

    /**
     * Ruft den Wert der messageCorrelator-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageCorrelator() {
        return messageCorrelator;
    }

    /**
     * Legt den Wert der messageCorrelator-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageCorrelator(String value) {
        this.messageCorrelator = value;
    }

    /**
     * Ruft den Wert der messageConverter-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageConverter() {
        return messageConverter;
    }

    /**
     * Legt den Wert der messageConverter-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageConverter(String value) {
        this.messageConverter = value;
    }

    /**
     * Ruft den Wert der timeout-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTimeout() {
        return timeout;
    }

    /**
     * Legt den Wert der timeout-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTimeout(String value) {
        this.timeout = value;
    }

    /**
     * Ruft den Wert der pollingInterval-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPollingInterval() {
        return pollingInterval;
    }

    /**
     * Legt den Wert der pollingInterval-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPollingInterval(String value) {
        this.pollingInterval = value;
    }

}
